## ----setup, include = FALSE----------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)

## ----echo=FALSE----------------------------------------------------------



a <- c('1','2','3','4','5','6','7','8','9','10','11','12','13','14','15','16','17')
b <- c('7','9','10','5','8','4','2','2','6','3','7','9','10','5','8','4','2')
dat <- data.frame(a,b)
names(dat) <- c('位置序号','加权因子')
dt <- data.frame(t(dat))
knitr::kable(dt)

## ----echo=F--------------------------------------------------------------

c1 <- c(0,1,2,3,4,5,6,7,8,9,10)
d <- c('1','0','X','9','8','7','6','5','4','3','2')
dat1 <- data.frame(c1,d)
names(dat1) <- c('余数','校验码')
dt2 <-data.frame(t(dat1))

knitr::kable(dt2)

